==> haskell-yesod-default-1.2.0-786-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-default
version:              1.2.0
visibility:           public
id:                   yesod-default-1.2.0-4mZMDCKJyIqAKm2psdjbcb
key:                  yesod-default-1.2.0-4mZMDCKJyIqAKm2psdjbcb
license:              MIT
maintainer:           Patrick Brisbin <pbrisbin@gmail.com>
author:               Patrick Brisbin
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:
    Default config and main functions for your yesod application (deprecated)

description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application

category:             Web, Yesod
abi:                  2bcd14c496ce097e280b9a26a197f09a
exposed:              True
exposed-modules:      Yesod.Default.Ignore
import-dirs:          /usr/lib/ghc-8.10.1/site-local/yesod-default-1.2.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/yesod-default-1.2.0
hs-libraries:         HSyesod-default-1.2.0-4mZMDCKJyIqAKm2psdjbcb
depends:
    base-4.14.0.0 yesod-core-1.6.18-DrlNEqVIzlZElcsNxwZfu3

haddock-interfaces:
    /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock

haddock-html:         /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-default-1.2.0-791-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-default
version:              1.2.0
visibility:           public
id:                   yesod-default-1.2.0-JeGx0Yc4ZTNAZqz65oWOk
key:                  yesod-default-1.2.0-JeGx0Yc4ZTNAZqz65oWOk
license:              MIT
maintainer:           Patrick Brisbin <pbrisbin@gmail.com>
author:               Patrick Brisbin
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:
    Default config and main functions for your yesod application (deprecated)

description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application

category:             Web, Yesod
abi:                  33005c8f26f64d39c4a5a4f7b6dc4be6
exposed:              True
exposed-modules:      Yesod.Default.Ignore
import-dirs:          /usr/lib/ghc-8.10.2/site-local/yesod-default-1.2.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/yesod-default-1.2.0
hs-libraries:         HSyesod-default-1.2.0-JeGx0Yc4ZTNAZqz65oWOk
depends:
    base-4.14.1.0 yesod-core-1.6.18-EF57ORRFdRL5s702USINOH

haddock-interfaces:
    /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock

haddock-html:         /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
